@@ -17,15 +17,29 @@ sub get_node_length {
     my $string = $node->content;
     return 0 if ( !length $string );
 
+    $string = _normailze_string($string);
+    my $line_count = _count_lines($string);
+
+    return $line_count;
+}
+
+sub _normailze_string {
+    my $string = shift;
+    
     # Replace whitespace-newline with newline
     $string
         =~ s/ \s+ \Q$INPUT_RECORD_SEPARATOR\E /$INPUT_RECORD_SEPARATOR/smxg;
     $string =~ s/\Q$INPUT_RECORD_SEPARATOR\E /$INPUT_RECORD_SEPARATOR/smxg;
     $string =~ s/ \A \s+ //msx;    # Remove leading whitespace
+    $string;
+}
+
+sub _count_lines {
+    my $string = shift;
     my @newlines = ( $string =~ /$ALL_NEWLINES_REGEX/smxg );
     my $line_count = scalar @newlines;
 
-# if the string is not empty and the last character is not a newline then add 1
+    # if the string is not empty and the last character is not a newline then add 1
     if ( length $string ) {
         my $last_char = substr $string, $LAST_CHARACTER, 1;
         if ( $last_char ne "$INPUT_RECORD_SEPARATOR" ) {
